@@ -3,6 +3,7 @@ import time
 import logging
 
 from fintix_modelcurator.const import *
+from fintix_modelcurator.repository import *
 
 
 def get_currenttime_ms():
@@ -32,5 +33,9 @@ def handle_error(error):
     handle_error(error, None)
 
 
+def upload_model(model_name):
+    ModelRepository.getInstance().upload_model(model_name)
+
+
 def get_model_save_path(model_name):
     return os.path.join(LOCAL_DEPLOY_MODEL_REPO, model_name)
